==> kdepim_4.13.3.orig.tar.xz: kdepim-4.13.3/noteshared/network/notehostdialog.h <==
/*******************************************************************
 KNotes -- Notes for the KDE project

 Copyright (c) 2003, Daniel Martin <daniel.martin@pirack.com>
               2004, Michael Brade <brade@kde.org>

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

 In addition, as a special exception, the copyright holders give
 permission to link the code of this program with any edition of
 the Qt library by Trolltech AS, Norway (or with modified versions
 of Qt that use the same license as Qt), and distribute linked
 combinations including the two.  You must obey the GNU General
 Public License in all respects for all of the code used other than
 Qt.  If you modify this file, you may extend this exception to
 your version of the file, but you are not obligated to do so.  If
 you do not wish to do so, delete this exception statement from
 your version.
*******************************************************************/

#ifndef KNOTEHOSTDIALOG_H
#define KNOTEHOSTDIALOG_H

#include <kdialog.h>
#include "noteshared_export.h"
class KHistoryComboBox;
class QTreeView;
class QModelIndex;


/**
 * A dialog that allows to select network service or request a hostname or IP address.
 */
namespace NoteShared {
class NOTESHARED_EXPORT NoteHostDialog : public KDialog
{
    Q_OBJECT
public:
    explicit NoteHostDialog( const QString &caption, QWidget *parent = 0 );
    ~NoteHostDialog();
    
    QString host() const;
    /**
     * Returns 0 if port was not specified
     */
    quint16 port() const;
    
private slots:
    void slotTextChanged( const QString & );
    void serviceSelected( const QModelIndex& );
    
    void slotServiceDoubleClicked(const QModelIndex &idx);
private:
    void readConfig();
    KHistoryComboBox *m_hostCombo;
    QTreeView *m_servicesView;
};
}

#endif

==> kdepim-15.08.2.tar.xz: kdepim-15.08.2/noteshared/network/notehostdialog.h <==
/*******************************************************************
 KNotes -- Notes for the KDE project

 Copyright (c) 2003, Daniel Martin <daniel.martin@pirack.com>
               2004, Michael Brade <brade@kde.org>

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

 In addition, as a special exception, the copyright holders give
 permission to link the code of this program with any edition of
 the Qt library by Trolltech AS, Norway (or with modified versions
 of Qt that use the same license as Qt), and distribute linked
 combinations including the two.  You must obey the GNU General
 Public License in all respects for all of the code used other than
 Qt.  If you modify this file, you may extend this exception to
 your version of the file, but you are not obligated to do so.  If
 you do not wish to do so, delete this exception statement from
 your version.
*******************************************************************/

#ifndef KNOTEHOSTDIALOG_H
#define KNOTEHOSTDIALOG_H

#include <QDialog>
#include "noteshared_export.h"
class KHistoryComboBox;
class QTreeView;
class QModelIndex;
class QPushButton;

/**
 * A dialog that allows to select network service or request a hostname or IP address.
 */
namespace NoteShared
{
class NOTESHARED_EXPORT NoteHostDialog : public QDialog
{
    Q_OBJECT
public:
    explicit NoteHostDialog(const QString &caption, QWidget *parent = Q_NULLPTR);
    ~NoteHostDialog();

    QString host() const;
    /**
     * Returns 0 if port was not specified
     */
    quint16 port() const;

private Q_SLOTS:
    void slotTextChanged(const QString &);
    void serviceSelected(const QModelIndex &);

    void slotServiceDoubleClicked(const QModelIndex &idx);
private:
    void readConfig();
    KHistoryComboBox *m_hostCombo;
    QTreeView *m_servicesView;
    QPushButton *mOkButton;
};
}

#endif
